@@ -128,8 +128,6 @@ def start_another_instance_of_application(context, application=None, start_via="
     start_application(context, application, start_via, command, session, kill)
 
 
-@step('Start {application} via {start_via}') # behave-common-steps decorator
-@step('Start "{application}" via command in {session}') # behave-common-steps decorator
 @step('Start application "{application}" | via "{start_via}" | via command "{command}" | via command | in "{session}"')
 def start_application(context, application=None, start_via="command", command=None, session=None, kill=True):
     application = get_application(context, application)
@@ -152,7 +150,6 @@ def start_application(context, application=None, start_via="command", command=No
 use_step_matcher("parse")  # stop using qecore matcher
 
 
-@step('Close app via gnome panel') # behave-common-steps decorator
 @step('Close application "{application}" via "{close_via}"')
 def application_in_not_running(context, application=None, close_via="gnome panel"):
     application = get_application(context, application)
@@ -186,7 +183,6 @@ def application_in_not_running(context, application=None, close_via="gnome panel
         )))
 
 
-@step('{application} shouldn\'t be running anymore') # behave-common-steps decorator
 @step('Application "{application}" is no longer running')
 def application_is_not_running(context, application):
     application = get_application(context, application)
@@ -194,7 +190,6 @@ def application_is_not_running(context, application):
         application.wait_before_app_closes(15)
 
 
-@step('{application} should start') # behave-common-steps decorator
 @step('Application "{application}" is running')
 def application_is_running(context, application):
     application = get_application(context, application)
@@ -203,15 +198,6 @@ def application_is_running(context, application):
         application.wait_before_app_starts(15)
 
 
-@step('Click "{target_name}" in GApplication menu') # behave-common-steps decorator
-def click_gapp_menu(context, target_name):
-    assert context.sandbox.default_application is not None, \
-        "You need to define a default application if you are using steps without root."
-    context.execute_steps(f'* Left click "{context.sandbox.default_application.name}" "menu" in "gnome-shell"')
-    sleep(0.5)
-    context.execute_steps(f'* Left click "{target_name}" "label" in "gnome-shell"')
-
-
 @step('Type text: "{text}"')
 def type_text(context, text):
     typeText(text)
@@ -222,7 +208,6 @@ def press_key(context, key_name):
     pressKey(key_name)
 
 
-@step('Press "{combo_name}"') # behave-common-steps decorator
 @step('Key combo: "{combo_name}"')
 def key_combo(context, combo_name):
     keyCombo(combo_name)
