@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
-import traceback
 import sys
+import traceback
 from dogtail.tree import root
 from qecore.utility import QE_DEVELOPMENT, Tuple
 
@@ -96,7 +96,6 @@ class GetNode:
         retry = kwargs.get("retry", False)
         expect_positive = kwargs.get("expect_positive", False)
 
-
         a11y_roots = {x.name: x for x in root.applications()}
 
         if a11y_root_name in a11y_roots:
@@ -110,11 +109,20 @@ class GetNode:
             try:
                 self.root = context.sandbox.default_application.instance
             except AttributeError:
+                traceback.print_exc(file=sys.stdout)
                 assert False, "".join((
                     "\nYou need to define a default application ",
-                    "if you are using steps without root."
+                    f"if you are using steps without root."
                 ))
 
+        application_list = [x.name for x in root.applications()]
+        if not self.root.name in application_list:
+            assert False, " ".join((
+                f"You are trying to do action in application: '{a11y_root_name}'",
+                f"which is not detected running.\n",
+                f"Detected applications are: '{application_list}'"
+            ))
+
         mouse_map = {
             "Left": 1,
             "Middle": 2,
@@ -124,7 +132,8 @@ class GetNode:
         try:
             self.m_btn = mouse_map[str(m_btn)]
         except KeyError:
-            assert False, "\nUnknown mouse button! Check your feature file!"
+            traceback.print_exc(file=sys.stdout)
+            assert False, f"\nUnknown mouse button! Check your feature file!\n"
 
         self.name = ("".join(name) if name != "Empty" else "") \
             if name != "None" else None
@@ -137,16 +146,19 @@ class GetNode:
         self.attr = attr if attr in defined_attributes else None if attr is None else False
         assert self.attr is not False, "\n".join((
             "\nUnknown attribute. Check your feature file!",
-            f"Attributes defined are {str(defined_attributes)}."
+            f"Attributes defined are '{str(defined_attributes)}'. You tried to use: '{self.attr}'"
         ))
 
         self.retry = retry if isinstance(retry, bool) else None
-        assert self.retry is not None, "\nUnknown retry state. Check your feature file!"
+        assert self.retry is not None, "\n".join((
+            "\nUnknown retry state. Check your feature file!",
+            f"Expected attribute is 'True' or 'False'. You tried to use: '{self.attr}'"
+        ))
 
         self.expect_positive = expect_positive if isinstance(expect_positive, bool) else None
         assert self.expect_positive is not None, "".join((
-            f"\nUnknown expect_positive state: {self.expect_positive}. ",
-            f"Check your feature file!"
+            f"\nUnknown expect_positive state. Check your feature file!"
+            f"Expected attribute is 'True' or 'False'. You tried to use: '{self.expect_positive}'"
         ))
 
 
@@ -172,7 +184,6 @@ class GetNode:
 
     def __exit__(self, exc_type, exc_value, trcb):
         if exc_type is not None:
-            traceback.print_exc(file=sys.stdout)
             return False
         return True
 
