@@ -1,5 +1,7 @@
 #!/usr/bin/env python3
 import os
+import sys
+import traceback
 from time import sleep
 import yaml
 from behave import step
@@ -231,12 +233,12 @@ class AccountData:
         with open(yaml_file, "rb") as data:
             try:
                 self.yaml_data = yaml.safe_load(data)
-            except yaml.YAMLError as error:
-                assert False,\
-                    " ".join((
-                        "Parsing YAML file was not successful.",
-                        f"Please check format of accounts.yaml file: {error}"
-                    ))
+            except yaml.YAMLError:
+                traceback.print_exc(file=sys.stdout)
+                assert False, " ".join((
+                    "Parsing YAML file was not successful.",
+                    f"Please check format of accounts.yaml file"
+                ))
 
 
     def parse_account_data(self):
@@ -247,28 +249,24 @@ class AccountData:
 
         try:
             self.name = self.yaml_data[self.account_id]["name"]
-        except Exception:
-            assert False,\
-                f"Name for account '{self.account_id}' is expected, but was not provided."
+        except KeyError:
+            raise KeyError(f"Name for account '{self.account_id}' is expected, but was not provided.")
 
         try:
             self.login = self.yaml_data[self.account_id]["login"]
-        except Exception:
-            assert False,\
-                f"Login for account '{self.account_id}' is expected, but was not provided."
+        except KeyError:
+            raise KeyError(f"Login for account '{self.account_id}' is expected, but was not provided.")
 
         try:
             self.password = self.yaml_data[self.account_id]["password"]
-        except Exception:
-            assert False,\
-                f"Password for account '{self.account_id}' is expected, but was not provided."
+        except KeyError:
+            raise KeyError(f"Password for account '{self.account_id}' is expected, but was not provided.")
 
         try:
             self.server = self.yaml_data[self.account_id]["server"]
-        except Exception:
+        except KeyError:
             if self.name == "Nextcloud" or self.name == "Microsoft Exchange":
-                assert False,\
-                    f"Server for account '{self.account_id}' is expected, but was not provided."
+                raise KeyError(f"Server for account '{self.account_id}' is expected, but was not provided.")
 
 
 def wait_until_progress_bar_dissapears_in(account_login_dialog):
@@ -316,6 +314,14 @@ def add_google_account(context, data, account_login_dialog):
         sleep(0.2)
 
     pressKey("End")
+
+    for _ in range(5):
+        sleep(1)
+        if not account_login_dialog.child("Allow", retry=False).showing:
+            pressKey("End")
+        else:
+            break
+
     allow_button.click()
 
     try:
@@ -621,6 +627,8 @@ def add_account(context, account_name, login=None, password=None, yaml_file=None
     accounts = Accounts(context)
     try:
         accounts.add_account(account_name, login=login, password=password, yaml_file=yaml_file)
+    except KeyError as error:
+        raise KeyError(error)
     except Exception:
         run(f"rm -rf {os.path.expanduser('~')}/.local/share/webkitgtk/*")
         accounts.add_account(account_name, login=login, password=password, yaml_file=yaml_file)
