@@ -55,10 +55,12 @@ class TestSandbox:
 
         self.attach_faf = True
         self.attach_faf_on_pass = True
+        self.logging_cursor = None
 
         self.workspace_return = False
 
         self.set_keyring = True
+        self.keyring_process_pid = None
 
         self.wait_for_stable_video = True
 
@@ -70,6 +72,7 @@ class TestSandbox:
         self.applications = []
         self.default_application = None
         self.retrieve_session_data()
+        self.set_g_debug_environment_variable()
         self.wait_until_shell_becomes_responsive()
 
         self.shell = root.application("gnome-shell")
@@ -700,6 +703,23 @@ class TestSandbox:
         self.screenshot_run_result = run("gnome-screenshot -f /tmp/screenshot.png", verbose=True)
 
 
+    def set_g_debug_environment_variable(self):
+        """
+        Setup environment variable G_DEBUG as 'fatal-criticals'.
+
+        .. note::
+
+            Do **NOT** call this by yourself. This method is called by :func:`__init__`.
+        """
+
+        if self.logging:
+            log.info("set_g_debug_environment_variable(self)")
+
+        # Environment value set upon checked field in Jenkins
+        if os.path.isfile("/tmp/headless_enable_fatal_critical"):
+            os.environ["G_DEBUG"] = "fatal-criticals"
+
+
     def attach_screenshot_to_report(self, context):
         """
         Attach screenshot to the html report upon failed test.
@@ -1028,7 +1048,10 @@ class TestSandbox:
                 "org.gnome.Shell.FocusSearch"
             )))
         else:
-            assert False, "Unknown option"
+            assert False, "".join((
+                f"Unknown option, only defined ones are 'show' or 'hide'.",
+                f"You tried to use: '{action}'"
+            ))
 
 
     #Using properties to preserve old api of attributes
