@@ -1,4 +1,8 @@
+#!/usr/bin/env python3
 import os
+import sys
+import traceback
+import shlex
 from functools import partial
 from subprocess import STDOUT, CalledProcessError, check_output
 from time import sleep, time
@@ -27,19 +31,24 @@ def get_application(context, application):
 
     app_class_to_return = None
     try:
-        app_class_to_return = getattr(context, application)
+        app_class_to_return = getattr(context, application) # get app from environment file
     except AttributeError:
-        for app in context.sandbox.applications:
+        for app in context.sandbox.applications: # get app from sandbox application list
             if app.component == application:
                 app_class_to_return = app
                 break
     except TypeError:
         app_class_to_return = context.sandbox.default_application
-        assert context.sandbox.default_application is not None, \
-            "Default application was not found. Check your environment file!"
+        assert context.sandbox.default_application is not None, "\n".join((
+            f"Default application was not found. Check your environment file!"
+            f"This is indication that no application was defined in environment.py file."
+        ))
+
+    assert app_class_to_return is not None, "\n".join((
+        f"Application '{application}' was not found.",
+        f"Possibly wrongly defined application in environment.py file or incorrect use of decorator in .feature file.",
+    ))
 
-    assert app_class_to_return is not None, \
-        "Application was not found. Check your environment or feature file!"
     assert not isinstance(app_class_to_return, str), \
         "Application class was not found. Usually indication of not installed application."
 
@@ -68,8 +77,10 @@ def get_application_root(context, application):
     try:
         root_to_return = root.application(application)
     except Exception:
-        assert False, \
-            "Application was not found in accessibility. Check your environment or feature file!"
+        traceback.print_exc(file=sys.stdout)
+        assert False, "".join((
+            "Application was not found in accessibility. Check your environment or feature file!",
+        ))
 
     return root_to_return
 
@@ -166,14 +177,15 @@ class HoldKey:
         >>>     do_some_stuff()
 
     """
-    from dogtail.rawinput import holdKey, releaseKey
 
     def __init__(self, key_name):
+        from dogtail.rawinput import holdKey
         self.key_name = key_name
         holdKey(self.key_name)
     def __enter__(self):
         return self
-    def __exit__(self, my_type, value, traceback):
+    def __exit__(self, my_type, value, trace):
+        from dogtail.rawinput import releaseKey
         releaseKey(self.key_name)
 
 
